import{v as o,a as r,b as i,c,j as p,T as d,k as _,P as u,C as b,M as f,s as l,l as s,m as g,n as m,p as y,q as v}from"./outputWidgets.9e8e14b2.js";import{s as w,a}from"./index.7440b90c.js";import"./pubsub.95c88303.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="725a921b-5b39-4aa6-9564-f6aa66b0630b",e._sentryDebugIdIdentifier="sentry-dbid-725a921b-5b39-4aa6-9564-f6aa66b0630b")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=p({render:()=>g(k)});d.init(),_(e,a),x.init(),e.use(a),e.use(u),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",f),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.bb159021.js.map
