import{cz as d}from"./outputWidgets.9e8e14b2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="2271c6f7-1f0c-4c1e-9bc4-1d6c3d0636bb",e._sentryDebugIdIdentifier="sentry-dbid-2271c6f7-1f0c-4c1e-9bc4-1d6c3d0636bb")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.99f1080e.js.map
