import{V as d,f as n,Q as p}from"./outputWidgets.9e8e14b2.js";import{B as f,b as i}from"./Base.8983363c.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="88dc9dcd-8ad8-4d94-99ed-b1f0aedd5a97",a._sentryDebugIdIdentifier="sentry-dbid-88dc9dcd-8ad8-4d94-99ed-b1f0aedd5a97")}catch{}})();const c=()=>p(i(),["component"]),r=(a,e)=>{let{slots:s,attrs:t}=e;const o=d(d(d({},a),{component:"div"}),t);return n(f,o,s)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=c();const b=r;export{b as A};
//# sourceMappingURL=Paragraph.49b33da6.js.map
