import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.036c4a35.js";import{K as f,P as l,L as d}from"./repository.be284bfa.js";import{d as b,b as u,ev as c,f as p,u as r}from"./outputWidgets.9e8e14b2.js";import{u as g}from"./index.7440b90c.js";import{a as y}from"./asyncComputed.855ae5ad.js";import{g as _}from"./api.79763515.js";import"./Text.f91b7e81.js";import"./Base.8983363c.js";import"./Typography.cc1d898e.js";import"./index.ad9c3bfa.js";import"./Link.6277100e.js";import"./Paragraph.49b33da6.js";import"./Title.6584a4fc.js";import"./index.903fcec9.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.c0430262.js";import"./index.cf4c23b9.js";import"./icons.2b48c800.js";import"./index.24364211.js";import"./ant-design.e931d931.js";import"./index.3f01ddfb.js";import"./Modal.6eb7b200.js";import"./index.06f03adb.js";import"./index.9afea8ad.js";import"./index.28256504.js";import"./CollapsePanel.b2daeb2e.js";import"./Form.00575eba.js";import"./hasIn.c9e055df.js";import"./Timeline.24eb5085.js";import"./index.36c0b0cd.js";import"./index.8add1aaf.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.5e7c3e1f.js";import"./workspaces.74e70c91.js";import"./runnerData.b090b21a.js";import"./url.eb89a751.js";import"./record.ff692408.js";import"./pubsub.95c88303.js";import"./scripts.e98d30d6.js";import"./envVars.847639a7.js";import"./ExpandOutlined.a45f1cf4.js";import"./Card.b572ce08.js";import"./TabPane.7b7a6d27.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="7a2c75b5-af77-42b7-958a-f478281f45fe",o._sentryDebugIdIdentifier="sentry-dbid-7a2c75b5-af77-42b7-958a-f478281f45fe")}catch{}})();const fo=b({__name:"Kanban",setup(o){const t=new l(g),e=new d("kanban"),{result:a}=y(_);return(k,w)=>{var i,n,m;return u(),c("div",null,[p(s,{"brand-name":((i=r(a))==null?void 0:i.brandName)||((n=r(a))==null?void 0:n.name),"logo-url":(m=r(a))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(f,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.268d7fc3.js.map
