import{C as t,A as m}from"./CollapsePanel.b2daeb2e.js";import{F as n}from"./Form.00575eba.js";import{aM as a,co as r}from"./outputWidgets.9e8e14b2.js";import{T as o,A as s}from"./Timeline.24eb5085.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="e87e4db4-5791-440f-beb6-ea19d46d20f0",e._sentryDebugIdIdentifier="sentry-dbid-e87e4db4-5791-440f-beb6-ea19d46d20f0")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=a;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.28256504.js.map
