import{B as d}from"./Base.8983363c.js";import{A as o}from"./Link.6277100e.js";import{A as r}from"./Paragraph.49b33da6.js";import{A as a}from"./Text.f91b7e81.js";import{A as i}from"./Title.6584a4fc.js";import{T as e}from"./Typography.cc1d898e.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="d62f89a9-d7cb-4190-8126-76174d4c6591",n._sentryDebugIdIdentifier="sentry-dbid-d62f89a9-d7cb-4190-8126-76174d4c6591")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=d;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.ad9c3bfa.js.map
