import{K as n,E as p,L as s}from"./repository.be284bfa.js";import{d as a,b as m,c,u as e}from"./outputWidgets.9e8e14b2.js";import{l as d}from"./index.7440b90c.js";import"./asyncComputed.855ae5ad.js";import"./api.c0430262.js";import"./index.cf4c23b9.js";import"./icons.2b48c800.js";import"./index.24364211.js";import"./ant-design.e931d931.js";import"./index.3f01ddfb.js";import"./Modal.6eb7b200.js";import"./Text.f91b7e81.js";import"./Base.8983363c.js";import"./Typography.cc1d898e.js";import"./index.06f03adb.js";import"./index.9afea8ad.js";import"./Paragraph.49b33da6.js";import"./index.ad9c3bfa.js";import"./Link.6277100e.js";import"./Title.6584a4fc.js";import"./index.28256504.js";import"./CollapsePanel.b2daeb2e.js";import"./Form.00575eba.js";import"./hasIn.c9e055df.js";import"./Timeline.24eb5085.js";import"./index.36c0b0cd.js";import"./index.8add1aaf.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.5e7c3e1f.js";import"./workspaces.74e70c91.js";import"./runnerData.b090b21a.js";import"./url.eb89a751.js";import"./record.ff692408.js";import"./pubsub.95c88303.js";import"./scripts.e98d30d6.js";import"./envVars.847639a7.js";import"./ExpandOutlined.a45f1cf4.js";import"./Card.b572ce08.js";import"./TabPane.7b7a6d27.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="1bcbdc45-2087-4430-8060-ece99f3a3389",t._sentryDebugIdIdentifier="sentry-dbid-1bcbdc45-2087-4430-8060-ece99f3a3389")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=a({__name:"WorkflowKanban",setup(t){const o=new p,r=new f,i=new s("kanban");return(u,b)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.d77796e0.js.map
