import{eN as n,eO as t}from"./outputWidgets.9e8e14b2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="67aefc88-2110-44aa-986a-1fdbe55a0e03",e._sentryDebugIdIdentifier="sentry-dbid-67aefc88-2110-44aa-986a-1fdbe55a0e03")}catch{}})();function d(e,a){return n(1,arguments),t(e,Date.now(),a)}export{d as f};
//# sourceMappingURL=index.9afea8ad.js.map
