import"./outputWidgets.9e8e14b2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="dc95da12-80fe-442d-8f7f-c8420e671055",e._sentryDebugIdIdentifier="sentry-dbid-dc95da12-80fe-442d-8f7f-c8420e671055")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.eb89a751.js.map
