import{ac as p,V as t,Q as r,f as c}from"./outputWidgets.9e8e14b2.js";import{B as f,b as l}from"./Base.8983363c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ea1763e2-8546-4892-ab57-eee55f3cc436",e._sentryDebugIdIdentifier="sentry-dbid-ea1763e2-8546-4892-ab57-eee55f3cc436")}catch{}})();const b=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:i}=s;const{ellipsis:n}=e;p();const d=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),i);return c(f,d,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.f91b7e81.js.map
