import{d as m,eB as f,u as e,b as d,c as u,ev as y,f as o,w as a,bv as _,ar as c,ex as g,e as b,eD as x}from"./outputWidgets.9e8e14b2.js";import"./router.637c147d.js";import"./index.5f48c045.js";import{O as w}from"./organization.c162ea20.js";import{a as k}from"./asyncComputed.855ae5ad.js";import{A}from"./Title.6584a4fc.js";import{A as B}from"./index.24364211.js";import{A as h}from"./index.36c0b0cd.js";import{A as C}from"./Text.f91b7e81.js";import{C as v}from"./Card.b572ce08.js";import"./Form.00575eba.js";import"./hasIn.c9e055df.js";import"./index.cf4c23b9.js";import"./record.ff692408.js";import"./pubsub.95c88303.js";import"./Base.8983363c.js";import"./Typography.cc1d898e.js";import"./TabPane.7b7a6d27.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="75378ccc-c97a-4a54-9b06-7ced3e945bc9",t._sentryDebugIdIdentifier="sentry-dbid-75378ccc-c97a-4a54-9b06-7ced3e945bc9")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=f().params.organizationId,{loading:p,result:l}=k(()=>w.get(n));return(z,N)=>e(p)?(d(),u(e(_),{key:0})):(d(),y("div",D,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(A),{level:3},{default:a(()=>[c("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(h),{style:{"margin-top":"0"}}),o(e(v),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[c("Plan")]),_:1}),b("div",I,x((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.560c8744.js.map
