import{v as t,b as s,ev as f}from"./outputWidgets.9e8e14b2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5556c4ff-1fb3-4474-988f-2de57baf2076",e._sentryDebugIdIdentifier="sentry-dbid-5556c4ff-1fb3-4474-988f-2de57baf2076")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),f("div",r,"Organization settings")}const c=t(o,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.3ec17f5c.js.map
